jQuery Test Suite

See this blog entry for more information.

Here are some links in a normal paragraph: Google, Google Groups (Link). This link has `class="blog"`: diveintomark

Everything inside the red border is inside a div with `id="foo"`.

This is a normal link: Yahoo

This link has `class="blog"`: Simon Willison's Weblog

Try them out:

Action:
foobar
test element Float test.

? Z
hi there
hidden

1. Rice
2. Beans
3. Blinis
4. Tofu

I'm hungry. I should...
...Eat lots of food... | ...Eat a little food... | ...Eat no food... ...Eat a burger... ...Eat some funyuns... ...Eat some funyuns...
1 2
fadeIn
fadeIn
fadeOut
fadeOut
show
show
hide
hide
hide
hide
togglein
togglein
toggleout
toggleout
toggleout
toggleout
slideUp
slideUp
slideDown
slideDown
slideUp
slideUp
slideToggleIn
slideToggleIn
slideToggleOut
slideToggleOut
fadeToggleIn
fadeToggleIn
fadeToggleOut
fadeToggleOut
fadeTo
fadeTo